@@ -1,18 +1,12 @@
 from __future__ import unicode_literals
 from datetime import timedelta
-from django.conf import settings
 from django.test import Client
 from django.contrib.auth.hashers import make_password
 from django.utils.timezone import now
-
-try:
-    from mock import patch
-except ImportError:  # nocv
-    from unittest.mock import patch
-
+from unittest.mock import patch
 from vstutils.utils import redirect_stdany
 from ._base import BaseTestCase, json
-from .hosts import InventoriesTestCase, InvBaseTestCase
+from .hosts import InventoriesTestCase, InvBaseTestCase  # noqa: F401
 from .executions import ProjectTestCase, BaseExecutionsTestCase
 from .openapi import OApiTestCase
 
@@ -64,7 +58,7 @@ class ApiUsersTestCase(ApiBaseTestCase):
 
     def test_is_active(self):
         client = self._login()
-        AUTH_PASSWORD_VALIDATORS = settings.AUTH_PASSWORD_VALIDATORS
+        AUTH_PASSWORD_VALIDATORS = self.settings_obj.AUTH_PASSWORD_VALIDATORS
         AUTH_PASSWORD_VALIDATORS[1]["OPTIONS"]["min_length"] = 5
         with self.settings(AUTH_PASSWORD_VALIDATORS=AUTH_PASSWORD_VALIDATORS):
             userdata = {"passwords": "ab",
@@ -224,8 +218,14 @@ class ApiUsersTestCase(ApiBaseTestCase):
         self.result(client.post, self.get_url('user'), 409, data)
         self._logout(client)
 
-    @patch('polemarch.main.hooks.http.Backend.execute')
-    def test_api_users_insert_and_delete(self, execute_method):
+    def test_api_users_insert_and_delete(self):
+        patch_obj_pth = '{}.main.hooks.http.Backend.execute'.format(
+            self.settings_obj.VST_PROJECT_LIB_NAME
+        )
+        with patch(patch_obj_pth) as execute_method:
+            return self._test_api_users_insert_and_delete(execute_method)
+
+    def _test_api_users_insert_and_delete(self, execute_method):
         self.sended = False
         hook_url = 'http://ex.com'
         hook_data = dict(
@@ -296,10 +296,10 @@ class ApiUsersTestCase(ApiBaseTestCase):
             self.get_bulk('team', dict(name='test_team'), 'add'),
             self.get_bulk('user', dict(username='test_user', **test_user_data), 'add'),
             self.get_mod_bulk(
-                'team', '<0[data][id]>', dict(username='te', **test_user_data), 'user'
+                'team', '<<0[data][id]>>', dict(username='te', **test_user_data), 'user'
             ),
             self.get_mod_bulk(
-                'team', '<0[data][id]>', dict(id='<1[data][id]>'), 'user'
+                'team', '<<0[data][id]>>', dict(id='<<1[data][id]>>'), 'user'
             ),
         ]
         results = self.make_bulk(bulk_data)
@@ -316,9 +316,9 @@ class ApiUsersTestCase(ApiBaseTestCase):
         # Test copy
         bulk_data = [
             self.get_mod_bulk('user', results[1]['data']['id'], {}, 'copy'),
-            self.get_bulk('user', {}, 'get', pk='<0[data][id]>'),
+            self.get_bulk('user', {}, 'get', pk='<<0[data][id]>>'),
             self.get_mod_bulk(
-                'team', results[0]['data']['id'], {}, 'user/<0[data][id]>', method='get'
+                'team', results[0]['data']['id'], {}, 'user/<<0[data][id]>>', method='get'
             ),
             self.get_mod_bulk('team', results[0]['data']['id'], {"name": "new"}, 'copy'),
             self.get_mod_bulk(
@@ -347,15 +347,14 @@ class ApiUsersTestCase(ApiBaseTestCase):
         self.assertCount(self.get_result("get", settings_url), 0)
 
 
-class APITestCase(ApiUsersTestCase, InventoriesTestCase, ProjectTestCase, OApiTestCase):
+class APITestCase(ProjectTestCase, OApiTestCase):
     def setUp(self):
         super(APITestCase, self).setUp()
 
     def test_api_versions_list(self):
         result = self.get_result("get", "/api/")
-        self.assertEqual(len(result), 2)
-        self.assertTrue(result.get(self._settings('VST_API_VERSION'), False))
-        self.assertTrue(result.get('openapi', False))
+        self.assertEqual(len(result['available_versions']), 1)
+        self.assertTrue(result['available_versions'].get(self._settings('VST_API_VERSION'), False))
 
     def test_api_v1_list(self):
         result = self.get_result('get', self.get_url())
@@ -370,7 +369,7 @@ class APITestCase(ApiUsersTestCase, InventoriesTestCase, ProjectTestCase, OApiTe
 
     def test_api_router(self):
         result = self.get_result('get', "/api/?format=json")
-        url = result[self._settings('VST_API_VERSION')].replace("http://testserver", "")
+        url = result['available_versions'][self._settings('VST_API_VERSION')].replace("http://testserver", "")
         self.get_result('get', url)
 
     def _generate_history(self, days_ago, count, status="OK"):
@@ -455,7 +454,7 @@ class APITestCase(ApiUsersTestCase, InventoriesTestCase, ProjectTestCase, OApiTe
         bulk_data = [
             {'type': "add", 'item': "token", 'data': data}
         ]
-        self.get_result("post", self.get_url('_bulk'), 415, data=json.dumps(bulk_data))
+        self.get_result("post", self.get_url('_bulk'), 404, data=json.dumps(bulk_data))
         self.get_result("put", self.get_url('_bulk'), 200, data=json.dumps(bulk_data))
 
         result = self.get_result("get", self.get_url('_bulk'))
@@ -470,3 +469,20 @@ class APITestCase(ApiUsersTestCase, InventoriesTestCase, ProjectTestCase, OApiTe
         self.assertIn("set", result["operations_types"])
         self.assertIn("del", result["operations_types"])
         self.assertIn("mod", result["operations_types"])
+
+    def test_lang(self):
+        bulk_data = [
+            {'data_type': ['_lang'], 'method': 'get'},
+            {'data_type': ['_lang', 'en'], 'method': 'get'},
+            {'data_type': ['_lang', 'ru'], 'method': 'get'},
+        ]
+
+        results = self.make_bulk(bulk_data)
+        self.assertEqual(results[0]['status'], 200)
+        self.assertEqual(results[0]['data']['count'], 2)
+        self.assertEqual(results[1]['data']['code'], 'en')
+        self.assertEqual(results[1]['data']['name'], 'English')
+        self.assertEqual(results[1]['data']['translations']['pmwuserscounter'], 'users counter')
+        self.assertEqual(results[2]['data']['code'], 'ru')
+        self.assertEqual(results[2]['data']['name'], 'Russian')
+        self.assertEqual(results[2]['data']['translations']['pmwuserscounter'], 'счетчик пользователей')
